.. _exceptions:


Exceptions
**********

.. currentmodule:: torchkge.exceptions

NotYetEvaluatedError
--------------------
.. autoclass:: torchkge.exceptions.exceptions.NotYetEvaluatedError
   :members:

SizeMismatchError
-----------------
.. autoclass:: torchkge.exceptions.exceptions.SizeMismatchError
   :members:

WrongDimensionError
-------------------
.. autoclass:: torchkge.exceptions.exceptions.WrongDimensionError
   :members:
